Basis:
- pv:
  - size
  - Storage Cluster
  - virtual_machine

Windows Form:
- Laufwerk Name (D, E, F)
- filesystem (ntfs)

Linux Form:
- vg name
- lv name
- path
- filesystem


Extra Filesystem Model & als ChoiceField ausgeben